@@ -11,8 +11,8 @@ class PluginTaskZ(pyutilib.workflow.TaskPlugin):
         pyutilib.workflow.Task.__init__(self, *args, **kwds)
         self.inputs.declare('x')
         self.inputs.declare('y')
-        self.parser.add_argument('--x', dest='x', type=int)
-        self.parser.add_argument('--y', dest='y', type=int)
+        self.add_argument('--x', dest='x', type=int)
+        self.add_argument('--y', dest='y', type=int)
         self.outputs.declare('z')
 
     def execute(self):
@@ -28,8 +28,8 @@ class PluginTaskY(pyutilib.workflow.TaskPlugin):
         pyutilib.workflow.Task.__init__(self, *args, **kwds)
         self.inputs.declare('X')
         self.inputs.declare('Y')
-        self.parser.add_argument('--X', dest='X', type=int)
-        self.parser.add_argument('--Y', dest='Y', type=int)
+        self.add_argument('--X', dest='X', type=int)
+        self.add_argument('--Y', dest='Y', type=int)
         self.outputs.declare('Z')
 
     def execute(self):
