@@ -77,8 +77,8 @@ class TaskBB(TaskB):
 
     def _create_parser(self, parser=None):
         pyutilib.workflow.Task._create_parser(self, parser)
-        self.parser.add_argument("--a",dest="a", type=int)
-        self.parser.add_argument("--i",dest="i", type=int)
+        self.add_argument("--a",dest="a", type=int)
+        self.add_argument("--i",dest="i", type=int)
 
 
 class TaskC(pyutilib.workflow.Task):
@@ -99,7 +99,7 @@ class TaskCC(TaskC):
 
     def _create_parser(self, parser=None):
         pyutilib.workflow.Task._create_parser(self, parser)
-        self.parser.add_argument("--i",dest="i", type=int)
+        self.add_argument("--i",dest="i", type=int)
 
 
 class TaskD(pyutilib.workflow.Task):
