@@ -20,13 +20,15 @@ for file in glob.glob(datadir+'example*.py'):
     # We use add_baseline_test instead of add_import_test because the latter does not seem to 
     # work when running with nosetests
     #
-    Test.add_baseline_test(cmd='cd %s; %s %s' % (datadir, sys.executable, file),  baseline=datadir+name+'.txt', name=name)
+    Test.add_baseline_test(cmd='%s %s' % (sys.executable, file),  baseline=datadir+name+'.txt', name=name, cwd=datadir, cmdfile=currdir+"cmd_"+name+".sh")
 
-# Find all *.sh files, and use them to define baseline tests
-for file in glob.glob(datadir+'*.sh'):
-    bname = basename(file)
-    name=bname.split('.')[0]
-    Test.add_baseline_test(cmd='cd %s; %s' % (datadir, file),  baseline=datadir+name+'.txt', name=name)
+if not sys.platform.startswith('win'):
+    # Find all *.sh files, and use them to define baseline tests
+    for file in glob.glob(datadir+'*.sh'):
+        bname = basename(file)
+        name=bname.split('.')[0]
+        #print file,bname,name
+        Test.add_baseline_test(cmd='cd %s; %s' % (datadir, file),  baseline=datadir+name+'.txt', name=name)
 
 # Execute the tests
 if __name__ == '__main__':
