@@ -32,6 +32,12 @@ def _collect_parser_groups(t):
             t._parser_group[key].parser = parser
             parser.add_argument_group(t._parser_group[key])
 
+def _set_arguments(t):
+        for arg in t._parser_arg:
+            args = arg[0]
+            kwargs = arg[1]
+            t._parser.add_argument(*args, **kwargs)
+
 
 class Workflow(Task):
 
@@ -131,6 +137,11 @@ class Workflow(Task):
         self._dfs_([self._start_task.id], _collect_parser_groups)
         parser.print_help()
 
+    def set_arguments(self, parser=None):
+        if parser is None:
+            parser = self._parser
+        self._dfs_([self._start_task.id], _set_arguments)
+
     def reset(self):
         return self._dfs_([self._start_task.id], lambda t: t.reset())
 
